==> gr-audio-alsa-0.2.tar.gz: gr-audio-alsa-0.2/src/audio_alsa.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _audio_alsa

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


class audio_alsa_sink_sptr(_object):
    """Proxy of C++ audio_alsa_sink_sptr class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, audio_alsa_sink_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, audio_alsa_sink_sptr, name)
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<audio_alsa_sink > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> audio_alsa_sink_sptr
        __init__(self,  p) -> audio_alsa_sink_sptr
        """
        _swig_setattr(self, audio_alsa_sink_sptr, 'this', _audio_alsa.new_audio_alsa_sink_sptr(*args))
        _swig_setattr(self, audio_alsa_sink_sptr, 'thisown', 1)
    def __deref__(*args): 
        """__deref__(self)"""
        return _audio_alsa.audio_alsa_sink_sptr___deref__(*args)

    def name(*args): 
        """name(self) -> string"""
        return _audio_alsa.audio_alsa_sink_sptr_name(*args)

    def input_signature(*args): 
        """input_signature(self) -> gr_io_signature_sptr"""
        return _audio_alsa.audio_alsa_sink_sptr_input_signature(*args)

    def output_signature(*args): 
        """output_signature(self) -> gr_io_signature_sptr"""
        return _audio_alsa.audio_alsa_sink_sptr_output_signature(*args)

    def unique_id(*args): 
        """unique_id(self) -> long"""
        return _audio_alsa.audio_alsa_sink_sptr_unique_id(*args)

    def output_multiple(*args): 
        """output_multiple(self) -> int"""
        return _audio_alsa.audio_alsa_sink_sptr_output_multiple(*args)

    def relative_rate(*args): 
        """relative_rate(self) -> double"""
        return _audio_alsa.audio_alsa_sink_sptr_relative_rate(*args)

    def check_topology(*args): 
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _audio_alsa.audio_alsa_sink_sptr_check_topology(*args)

    def detail(*args): 
        """detail(self) -> gr_block_detail_sptr"""
        return _audio_alsa.audio_alsa_sink_sptr_detail(*args)

    def set_detail(*args): 
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _audio_alsa.audio_alsa_sink_sptr_set_detail(*args)

    def __del__(self, destroy=_audio_alsa.delete_audio_alsa_sink_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class audio_alsa_sink_sptrPtr(audio_alsa_sink_sptr):
    def __init__(self, this):
        _swig_setattr(self, audio_alsa_sink_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, audio_alsa_sink_sptr, 'thisown', 0)
        _swig_setattr(self, audio_alsa_sink_sptr,self.__class__,audio_alsa_sink_sptr)
_audio_alsa.audio_alsa_sink_sptr_swigregister(audio_alsa_sink_sptrPtr)


def audio_alsa_sink_block(*args):
    """audio_alsa_sink_block(audio_alsa_sink_sptr r) -> gr_block_sptr"""
    return _audio_alsa.audio_alsa_sink_block(*args)
audio_alsa_sink_sptr.block = lambda self: audio_alsa_sink_block (self)
audio_alsa_sink_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())

class audio_alsa_source_sptr(_object):
    """Proxy of C++ audio_alsa_source_sptr class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, audio_alsa_source_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, audio_alsa_source_sptr, name)
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<audio_alsa_source > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> audio_alsa_source_sptr
        __init__(self,  p) -> audio_alsa_source_sptr
        """
        _swig_setattr(self, audio_alsa_source_sptr, 'this', _audio_alsa.new_audio_alsa_source_sptr(*args))
        _swig_setattr(self, audio_alsa_source_sptr, 'thisown', 1)
    def __deref__(*args): 
        """__deref__(self)"""
        return _audio_alsa.audio_alsa_source_sptr___deref__(*args)

    def name(*args): 
        """name(self) -> string"""
        return _audio_alsa.audio_alsa_source_sptr_name(*args)

    def input_signature(*args): 
        """input_signature(self) -> gr_io_signature_sptr"""
        return _audio_alsa.audio_alsa_source_sptr_input_signature(*args)

    def output_signature(*args): 
        """output_signature(self) -> gr_io_signature_sptr"""
        return _audio_alsa.audio_alsa_source_sptr_output_signature(*args)

    def unique_id(*args): 
        """unique_id(self) -> long"""
        return _audio_alsa.audio_alsa_source_sptr_unique_id(*args)

    def output_multiple(*args): 
        """output_multiple(self) -> int"""
        return _audio_alsa.audio_alsa_source_sptr_output_multiple(*args)

    def relative_rate(*args): 
        """relative_rate(self) -> double"""
        return _audio_alsa.audio_alsa_source_sptr_relative_rate(*args)

    def check_topology(*args): 
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _audio_alsa.audio_alsa_source_sptr_check_topology(*args)

    def detail(*args): 
        """detail(self) -> gr_block_detail_sptr"""
        return _audio_alsa.audio_alsa_source_sptr_detail(*args)

    def set_detail(*args): 
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _audio_alsa.audio_alsa_source_sptr_set_detail(*args)

    def __del__(self, destroy=_audio_alsa.delete_audio_alsa_source_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class audio_alsa_source_sptrPtr(audio_alsa_source_sptr):
    def __init__(self, this):
        _swig_setattr(self, audio_alsa_source_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, audio_alsa_source_sptr, 'thisown', 0)
        _swig_setattr(self, audio_alsa_source_sptr,self.__class__,audio_alsa_source_sptr)
_audio_alsa.audio_alsa_source_sptr_swigregister(audio_alsa_source_sptrPtr)

def sink(*args):
    """
    sink(int sampling_freq, string dev="", double period_time=-1, 
        int nperiods=-1) -> audio_alsa_sink_sptr
    sink(int sampling_freq, string dev="", double period_time=-1) -> audio_alsa_sink_sptr
    sink(int sampling_freq, string dev="") -> audio_alsa_sink_sptr
    sink(int sampling_freq) -> audio_alsa_sink_sptr
    """
    return _audio_alsa.sink(*args)


def audio_alsa_source_block(*args):
    """audio_alsa_source_block(audio_alsa_source_sptr r) -> gr_block_sptr"""
    return _audio_alsa.audio_alsa_source_block(*args)
audio_alsa_source_sptr.block = lambda self: audio_alsa_source_block (self)
audio_alsa_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def source(*args):
    """
    source(int sampling_freq, string dev="", double period_time=-1, 
        int nperiods=-1) -> audio_alsa_source_sptr
    source(int sampling_freq, string dev="", double period_time=-1) -> audio_alsa_source_sptr
    source(int sampling_freq, string dev="") -> audio_alsa_source_sptr
    source(int sampling_freq) -> audio_alsa_source_sptr
    """
    return _audio_alsa.source(*args)

==> gr-audio-alsa-0.3.tar.gz: gr-audio-alsa-0.3/src/audio_alsa.py <==
# This file was created automatically by SWIG 1.3.27.
# Don't modify this file, modify the SWIG interface instead.

import _audio_alsa

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


def _swig_setattr_nondynamic_method(set):
    def set_attr(self,name,value):
        if hasattr(self,name) or (name in ("this", "thisown")):
            set(self,name,value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


class audio_alsa_source_sptr(object):
    """Proxy of C++ audio_alsa_source_sptr class"""
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<audio_alsa_source > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> audio_alsa_source_sptr
        __init__(self,  p) -> audio_alsa_source_sptr
        """
        newobj = _audio_alsa.new_audio_alsa_source_sptr(*args)
        self.this = newobj.this
        self.thisown = 1
        del newobj.thisown
    def __deref__(*args):
        """__deref__(self)"""
        return _audio_alsa.audio_alsa_source_sptr___deref__(*args)

    def start(*args):
        """start(self) -> bool"""
        return _audio_alsa.audio_alsa_source_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _audio_alsa.audio_alsa_source_sptr_stop(*args)

    def name(*args):
        """name(self) -> string"""
        return _audio_alsa.audio_alsa_source_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _audio_alsa.audio_alsa_source_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _audio_alsa.audio_alsa_source_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _audio_alsa.audio_alsa_source_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _audio_alsa.audio_alsa_source_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _audio_alsa.audio_alsa_source_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _audio_alsa.audio_alsa_source_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _audio_alsa.audio_alsa_source_sptr_check_topology(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _audio_alsa.audio_alsa_source_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _audio_alsa.audio_alsa_source_sptr_set_detail(*args)

    def __del__(self, destroy=_audio_alsa.delete_audio_alsa_source_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class audio_alsa_source_sptrPtr(audio_alsa_source_sptr):
    def __init__(self, this):
        self.this = this
        if not hasattr(self,"thisown"): self.thisown = 0
        self.__class__ = audio_alsa_source_sptr
_audio_alsa.audio_alsa_source_sptr_swigregister(audio_alsa_source_sptrPtr)


def audio_alsa_source_block(*args):
    """audio_alsa_source_block(audio_alsa_source_sptr r) -> gr_block_sptr"""
    return _audio_alsa.audio_alsa_source_block(*args)
audio_alsa_source_sptr.block = lambda self: audio_alsa_source_block (self)
audio_alsa_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())

class audio_alsa_sink_sptr(object):
    """Proxy of C++ audio_alsa_sink_sptr class"""
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<audio_alsa_sink > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> audio_alsa_sink_sptr
        __init__(self,  p) -> audio_alsa_sink_sptr
        """
        newobj = _audio_alsa.new_audio_alsa_sink_sptr(*args)
        self.this = newobj.this
        self.thisown = 1
        del newobj.thisown
    def __deref__(*args):
        """__deref__(self)"""
        return _audio_alsa.audio_alsa_sink_sptr___deref__(*args)

    def name(*args):
        """name(self) -> string"""
        return _audio_alsa.audio_alsa_sink_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _audio_alsa.audio_alsa_sink_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _audio_alsa.audio_alsa_sink_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _audio_alsa.audio_alsa_sink_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _audio_alsa.audio_alsa_sink_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _audio_alsa.audio_alsa_sink_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _audio_alsa.audio_alsa_sink_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _audio_alsa.audio_alsa_sink_sptr_check_topology(*args)

    def start(*args):
        """start(self) -> bool"""
        return _audio_alsa.audio_alsa_sink_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _audio_alsa.audio_alsa_sink_sptr_stop(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _audio_alsa.audio_alsa_sink_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _audio_alsa.audio_alsa_sink_sptr_set_detail(*args)

    def __del__(self, destroy=_audio_alsa.delete_audio_alsa_sink_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class audio_alsa_sink_sptrPtr(audio_alsa_sink_sptr):
    def __init__(self, this):
        self.this = this
        if not hasattr(self,"thisown"): self.thisown = 0
        self.__class__ = audio_alsa_sink_sptr
_audio_alsa.audio_alsa_sink_sptr_swigregister(audio_alsa_sink_sptrPtr)

def source(*args):
    """
    source(int sampling_freq, string dev="", double period_time=-1, 
        int nperiods=-1) -> audio_alsa_source_sptr
    source(int sampling_freq, string dev="", double period_time=-1) -> audio_alsa_source_sptr
    source(int sampling_freq, string dev="") -> audio_alsa_source_sptr
    source(int sampling_freq) -> audio_alsa_source_sptr
    """
    return _audio_alsa.source(*args)


def audio_alsa_sink_block(*args):
    """audio_alsa_sink_block(audio_alsa_sink_sptr r) -> gr_block_sptr"""
    return _audio_alsa.audio_alsa_sink_block(*args)
audio_alsa_sink_sptr.block = lambda self: audio_alsa_sink_block (self)
audio_alsa_sink_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())



def sink(*args):
    """
    sink(int sampling_freq, string dev="", double period_time=-1, 
        int nperiods=-1) -> audio_alsa_sink_sptr
    sink(int sampling_freq, string dev="", double period_time=-1) -> audio_alsa_sink_sptr
    sink(int sampling_freq, string dev="") -> audio_alsa_sink_sptr
    sink(int sampling_freq) -> audio_alsa_sink_sptr
    """
    return _audio_alsa.sink(*args)
